/***********************************************
 * Licensed Materials - Property of IBM
 * 
 * 5724-R31, 5655-S30
 *
 * (C) Copyright IBM Corp. 2011 All Rights Reserved.
 * 
 * US Government Users Restricted Rights - Use, duplication or
 * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 ***********************************************
 */
package com.ibm.websphere.icp.integration.ejb;

import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.GregorianCalendar;
import java.util.logging.Level;
import java.util.logging.Logger;

import javax.jms.MapMessage;
import javax.xml.datatype.DatatypeFactory;
import javax.xml.datatype.XMLGregorianCalendar;
import javax.xml.rpc.holders.CalendarHolder;
import javax.xml.rpc.holders.StringHolder;
import javax.xml.ws.Holder;

import localhost._9080.teamworks.webservices.ipm.networkinboundservice.NetworkInboundService;
import localhost._9080.teamworks.webservices.ipm.networkinboundservice.TroubleTicket;

import com.ibm.websphere.icp.integration.util.IntegrationConstants;
import com.ibm.www.ContactPerson;
import com.ibm.www.CreateRecordOfResourceFault;
import com.ibm.www.CreateRecordOfResourceFaultExport1_CreateRecordOfResourceFaultHttpServiceLocator;
import com.ibm.www.Customer;
import com.ibm.www.ManagementInfo;
import com.ibm.www.Specification;
import com.ibm.www.holders.ContactPersonHolder;
import com.ibm.www.holders.ManagementInfoHolder;
import com.ibm.www.holders.SpecificationHolder;

public class JMSIntegrationListenerHelper implements IntegrationConstants {
	
	protected Logger logger = Logger.getLogger(this.getClass().getName());

	public JMSIntegrationListenerHelper() {
		super();
	}

	protected void log(String msg) {    	
		logger.info(msg);    	
	}

	protected void logError(String level, String severity, String msg) {    	
		StringBuffer buf = new StringBuffer("Error Details:");		
		buf.append(NEWLINE);
		buf.append("Level:");
		buf.append(level);
		buf.append(NEWLINE);
		buf.append("Severity:");
		buf.append(severity);
		buf.append(NEWLINE);
		buf.append("Error Msg:");
		buf.append(msg);		
		logger.info(buf.toString());    	
	}

    /**
     * This will call the WS and send the message.
     * 
     * @param msg 
     *  
     */
    public void processMessage(MapMessage msg) {
    	log("in processMessage() \n" + msg);
    	
    	try {

    		String corelationID = msg.getStringProperty(JMSMESSAGE_ID); 
    		SimpleDateFormat sdf = new SimpleDateFormat(DATE_FORMAT_MM_DD_YYYY);
    		
    		String incidentName = msg.getString(INCIDENT_NAME);
   			String description = msg.getString(DESCRIPTION);   			
   			String addressDesc = msg.getString(ADDRESS_DESCRIPTION);
   			String customerFirstName = msg.getString(CONTACT_PERSON);
   			String notificationDateTime = msg.getString(NOTIFICATION_TIME);
   			String effectiveDateTime = msg.getString(EFFECTIVE_TIME);
   			String endDateTime = msg.getString(END_TIME);
    		String previouslyReported = msg.getString(PREVIOUSLY_REPORTED);
    		String perceivedSeverity = msg.getString(PERCEIVED_SEVERITY);
   			
    		//check loglevel before creating the msg @gsm
    		if ( logger.isLoggable(Level.INFO)) {
    			StringBuffer buf = new StringBuffer();    			
    			buf.append(JMSMESSAGE_ID).append(COLON);
    			buf.append(corelationID);
    			buf.append(INCIDENT_NAME).append(COLON);
    			buf.append(incidentName);
    			buf.append(NEWLINE).append(DESCRIPTION).append(COLON);
    			buf.append(description);
    			buf.append(NEWLINE).append(CONTACT_PERSON).append(COLON);
    			buf.append(customerFirstName);
    			buf.append(NEWLINE).append(ADDRESS_DESCRIPTION).append(COLON);
    			buf.append(addressDesc);
    			buf.append(NEWLINE).append(NOTIFICATION_TIME).append(COLON);
    			buf.append(notificationDateTime);
    			buf.append(NEWLINE).append(EFFECTIVE_TIME).append(COLON);
    			buf.append(effectiveDateTime);
    			buf.append(NEWLINE).append(END_TIME).append(COLON);
    			buf.append(endDateTime);
    			buf.append(NEWLINE).append(PREVIOUSLY_REPORTED).append(COLON);
    			buf.append(previouslyReported);
    			buf.append(NEWLINE).append(PERCEIVED_SEVERITY).append(COLON);
    			buf.append(perceivedSeverity);
    			
    			log(buf.toString());
    		}    		
    		    		
    		
    		String invokeProcessInProcessDeginer = msg.getString(IBM_PROCESS_DESIGNER);
    		if (invokeProcessInProcessDeginer == null || 
    				(invokeProcessInProcessDeginer != null && invokeProcessInProcessDeginer.isEmpty())) {
    			invokeProcessInProcessDeginer = msg.getString("response");
    		}
    		
    		log("invokeProcessInProcessDeginer: " + invokeProcessInProcessDeginer);
    		
    		if (invokeProcessInProcessDeginer != null && IBM_PROCESS_DESIGNER.equalsIgnoreCase(invokeProcessInProcessDeginer)) {
    			//Make a call to BPD based IPM processes
    			NetworkInboundService stub = new NetworkInboundService();
    			TroubleTicket troubleTicket = new TroubleTicket();

    			troubleTicket.setSiteId(corelationID);
    			
    			troubleTicket.setTroubleType(incidentName);
    			
    			troubleTicket.setDescription(description);
    			
    			troubleTicket.setOwner(customerFirstName);
    			
    			troubleTicket.setTroubleLocation(addressDesc);
    			
    			GregorianCalendar gCal = new GregorianCalendar();
    			gCal.setGregorianChange(sdf.parse(notificationDateTime));
    			XMLGregorianCalendar xmlCal = DatatypeFactory.newInstance().newXMLGregorianCalendar(gCal);
    			troubleTicket.setReportDate(xmlCal);
    			
    			gCal = new GregorianCalendar();
    			gCal.setGregorianChange(sdf.parse(effectiveDateTime));
    			xmlCal = DatatypeFactory.newInstance().newXMLGregorianCalendar(gCal);
    			troubleTicket.setServiceUnavailableBeginTime(xmlCal);
    			
    			gCal = new GregorianCalendar();
    			gCal.setGregorianChange(sdf.parse(endDateTime));
    			xmlCal = DatatypeFactory.newInstance().newXMLGregorianCalendar(gCal);
    			troubleTicket.setLastUpdateTime(xmlCal);
    			
    			troubleTicket.setPreviouslyReportedProblem(previouslyReported);
    			
    			troubleTicket.setPerceivedSeverity(perceivedSeverity);
    			
    			Holder<TroubleTicket> troubleTicketHolder = new Holder<TroubleTicket>(troubleTicket);
				stub.getNetworkInboundServiceSoap().processTroubleTicket(troubleTicketHolder);
    		} else {
    			
       			StringHolder addressDescription = new StringHolder(addressDesc);
       			ContactPerson cpValue = new ContactPerson();
       			Customer cust = new Customer();   			
       			cust.setFirstName(customerFirstName);   			
       			cpValue.setCustomer(cust);
       			ContactPersonHolder contactPerson = new ContactPersonHolder(cpValue);
        		    		
    			Calendar cal = Calendar.getInstance();
    			cal.setTime(sdf.parse(notificationDateTime));
    			CalendarHolder notificationTime = new CalendarHolder(cal);
    			
    			cal = Calendar.getInstance();
    			cal.setTime(sdf.parse(effectiveDateTime));			
    			CalendarHolder effectiveTime = new CalendarHolder(cal);
        		
    			cal = Calendar.getInstance();
    			cal.setTime(sdf.parse(endDateTime));			
        		CalendarHolder endTime = new CalendarHolder(cal);    		
        		
        		
        		Specification specification = new Specification();
        		specification.setId(corelationID);
        		SpecificationHolder addressSpecification =  new SpecificationHolder(specification);
        		    		
        		ManagementInfo Info = new ManagementInfo();    		
        		Info.setName(contactPerson.value.getCustomer().getFirstName());
        		Info.setCategory(description);
        		Info.setType(perceivedSeverity);
        		ManagementInfoHolder managementInfo = new ManagementInfoHolder(Info);
    			
    			//Make a call to BPEL based IPM processes
	    		//CreateRecordOfResourceFault stub = new CreateRecordOfResourceFaultProxy();
        		CreateRecordOfResourceFault stub = new CreateRecordOfResourceFaultExport1_CreateRecordOfResourceFaultHttpServiceLocator()
	    		.getCreateRecordOfResourceFaultExport_CreateRecordOfResourceFaultHttpPort(); 
	    		
	    		if ( logger.isLoggable(Level.INFO)) log("CALL to createRecordOfResourceFault");
	    		stub.createRecordOfResourceFault(new StringHolder(incidentName), new SpecificationHolder(), contactPerson, 
	    				notificationTime, effectiveTime, endTime, managementInfo, new StringHolder("0"), 
	    				addressDescription, addressSpecification);
    		}			
		} catch (Exception e) {
			logError( ERROR, FATAL, e.getMessage());
			//e.printStackTrace();
		}
	}
	
	
}