/***********************************************
 * Licensed Materials - Property of IBM
 * 
 * 5724-R31, 5655-S30
 *
 * (C) Copyright IBM Corp. 2011 All Rights Reserved.
 * 
 * US Government Users Restricted Rights - Use, duplication or
 * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 ***********************************************
 */

package com.ibm.websphere.icp.telecom.integration;

import java.util.Hashtable;

import javax.jms.Connection;
import javax.jms.ConnectionFactory;
import javax.jms.Destination;
import javax.jms.MessageProducer;
import javax.jms.Session;
import javax.jms.TextMessage;
import javax.naming.Context;
import javax.naming.InitialContext;
import javax.naming.NamingException;

import com.ibm.websphere.icp.integration.ejb.JMSIntegrationListenerHelper;
import com.ibm.websphere.sca.ServiceManager;
import commonj.sdo.DataObject;

public class ReportTroubleResolutionImpl extends JMSIntegrationListenerHelper {

	private MessageProducer producer;
	private Session jmsSession;
	private Connection conn;
	private InitialContext context;
	private String cfJNDI;
	private String qJNDI;

	/**
	 * Default constructor.
	 */
	public ReportTroubleResolutionImpl() {
		super();
        
        try {
    		cfJNDI = IntegrationProperties.getString("externalCF"); //$NON-NLS-1$
    		qJNDI = IntegrationProperties.getString("externalQ"); //$NON-NLS-1$
    		System.out.println(NEWLINE);
    		System.out.println(NEWLINE);
    		System.out.println(NEWLINE);
    		System.out.println(NEWLINE);
    		System.out.println(NEWLINE);
    		System.out.println("cfJNDI:"+cfJNDI);
    		
    		Hashtable env = new Hashtable();
    		env.put(Context.SECURITY_CREDENTIALS, IntegrationProperties.getString("username")); //$NON-NLS-1$
            env.put(Context.SECURITY_PRINCIPAL, IntegrationProperties.getString("password")); //$NON-NLS-1$
			context = new InitialContext(env);
		} catch (NamingException e) {
			logError(ERROR, FATAL, e.getMessage());
		}   
	}

	/**
	 * Return a reference to the component service instance for this implementation
	 * class.  This method should be used when passing this service to a partner reference
	 * or if you want to invoke this component service asynchronously.    
	 *
	 * @generated (com.ibm.wbit.java)
	 */
	@SuppressWarnings("unused")
	private Object getMyService() {
		return (Object) ServiceManager.INSTANCE.locateService("self"); //$NON-NLS-1$
	}

	/**
	 * Method generated to support implementation of operation "modifyRecordOfResourceFault" defined for WSDL port type 
	 * named "ModifyRecordOfResourceFault".
	 * 
	 * The presence of commonj.sdo.DataObject as the return type and/or as a parameter 
	 * type conveys that it is a complex type. Please refer to the WSDL Definition for more information 
	 * on the type of input, output and fault(s).
	 */
	/**
	 * @param aIncident
	 * @return
	 */
	public DataObject modifyRecordOfResourceFault(DataObject aIncident) {
		log("modifyRecordOfResourceFault - will be sent to Impact"); //$NON-NLS-1$
		try{
			
			ConnectionFactory cf = (ConnectionFactory)context.lookup(cfJNDI);   
			conn = cf.createConnection();   
			jmsSession = conn.createSession(false, Session.AUTO_ACKNOWLEDGE);						    
			producer = jmsSession.createProducer((Destination)context.lookup(qJNDI));   
			
			TextMessage txtmessage = jmsSession.createTextMessage();   
			if (aIncident.getDataObject(ADDRESS_SPECIFICATION) != null) {
				String corelationId = aIncident.getDataObject(ADDRESS_SPECIFICATION).getString(ID);
				txtmessage.setJMSCorrelationID(corelationId);
			}

			if (aIncident.getDataObject(CONTACT_PERSON) !=null &&
					aIncident.getDataObject(CONTACT_PERSON).getDataObject(CUSTOMER) !=null  &&
					aIncident.getDataObject(CONTACT_PERSON).getDataObject(CUSTOMER).getString(STATUS) !=null ) {
				String status = aIncident.getDataObject(CONTACT_PERSON).getDataObject(CUSTOMER).getString(STATUS);
				txtmessage.setText(status);
			}
			//send the text message
			producer.send(txtmessage);
		} 
		catch (Exception e) {			
			logError(ERROR, FATAL, e.getMessage());
			e.printStackTrace();
			throw new RuntimeException(e);
		} 
		finally {
			// Close the jms session and connection
			try {
				if (producer != null) producer.close();
				if (jmsSession != null) jmsSession.close();   
				if (conn != null) conn.close();   
			} catch (Exception e) {				
				logError(ERROR, FATAL, e.getMessage());
			}   			
		}		
		return aIncident;
	}

}