/***********************************************
 * Licensed Materials - Property of IBM
 * 
 * 5724-R31, 5655-S30
 *
 * (C) Copyright IBM Corp. 2011 All Rights Reserved.
 * 
 * US Government Users Restricted Rights - Use, duplication or
 * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 ***********************************************
 */
package com.ibm.websphere.icp.integration.jms;

import java.util.Hashtable;

import javax.jms.Connection;
import javax.jms.ConnectionFactory;
import javax.jms.Destination;
import javax.jms.MapMessage;
import javax.jms.MessageProducer;
import javax.jms.Session;
import javax.naming.Context;
import javax.naming.InitialContext;
import javax.naming.NamingException;

import com.ibm.websphere.sca.ServiceManager;
import commonj.sdo.DataObject;

public class CreateRecordOfReaourceFaultImpl {
	
	private MessageProducer producer;
	private Session jmsSession;
	private Connection conn;
	private InitialContext context;
	private String cfJNDI;
	private String qJNDI;

	/**
	 * Default constructor.
	 */
	public CreateRecordOfReaourceFaultImpl() {
		super();
		
        try {
    		cfJNDI = IntegrationProperties.getString("ipmCF"); //$NON-NLS-1$
    		qJNDI = IntegrationProperties.getString("ipmQ"); //$NON-NLS-1$
    		
    		Hashtable env = new Hashtable();
    		env.put(Context.SECURITY_CREDENTIALS, IntegrationProperties.getString("username")); //$NON-NLS-1$
            env.put(Context.SECURITY_PRINCIPAL, IntegrationProperties.getString("password")); //$NON-NLS-1$
			context = new InitialContext(env);
		} catch (NamingException e) {
			throw new RuntimeException(e);
		}   

	}

	/**
	 * Return a reference to the component service instance for this implementation
	 * class.  This method should be used when passing this service to a partner reference
	 * or if you want to invoke this component service asynchronously.    
	 *
	 * @generated (com.ibm.wbit.java)
	 */
	@SuppressWarnings("unused")
	private Object getMyService() {
		return (Object) ServiceManager.INSTANCE.locateService("self");
	}

	/**
	 * Method generated to support implementation of operation "createRecordOfReaourceFault" defined for WSDL port type 
	 * named "CreateRecordOfReaourceFault".
	 * 
	 * The presence of commonj.sdo.DataObject as the return type and/or as a parameter 
	 * type conveys that it is a complex type. Please refer to the WSDL Definition for more information 
	 * on the type of input, output and fault(s).
	 */
	public DataObject createRecordOfResourceFault(
			DataObject createRecordOfResourceFault) {
		try{
			ConnectionFactory cf = (ConnectionFactory)context.lookup(cfJNDI);   
			conn = cf.createConnection();   
			jmsSession = conn.createSession(false,Session.AUTO_ACKNOWLEDGE);   
			    
			Destination destination = (Destination)context.lookup(qJNDI);
			    
			//session requires the destination to create the producer   
			MessageProducer producer = jmsSession.createProducer(destination);   
			
			MapMessage message = jmsSession.createMapMessage();   
			message.setString("incidentName", createRecordOfResourceFault.getString("incidentName"));
			message.setString("contactPerson", createRecordOfResourceFault.getString("contactPerson"));
			message.setString("description", createRecordOfResourceFault.getString("description"));
			message.setString("notificationTime", createRecordOfResourceFault.getString("notificationTime"));
			message.setString("effectiveTime", createRecordOfResourceFault.getString("effectiveTime"));
			message.setString("endTime", createRecordOfResourceFault.getString("endTime"));
			message.setString("addressDescription", createRecordOfResourceFault.getString("addressDescription"));
			message.setString("previouslyReported", createRecordOfResourceFault.getString("previouslyReported"));
			message.setString("perceivedSeverity", createRecordOfResourceFault.getString("perceivedSeverity"));
			message.setString("response", createRecordOfResourceFault.getString("response"));
			
			//Can be used if requried to be used for BPDs
			message.setString("IBM_PROCESS_DESIGNER", createRecordOfResourceFault.getString("response"));
			
			producer.send(message);			
		}
		catch (Exception e) {
			throw new RuntimeException(e);
		} 
		finally {
			// Close the jms session and connection
			try {
				if (producer != null) producer.close();
				if (jmsSession != null) jmsSession.close();   
				if (conn != null) conn.close();   
			} catch (Exception e) {				
				throw new RuntimeException(e);
			}   			
		}		
		
		return createRecordOfResourceFault;
	}

}