/***********************************************
 * Licensed Materials - Property of IBM
 * 
 * 5724-R31, 5655-S30
 *
 * (C) Copyright IBM Corp. 2010, 2011 All Rights Reserved.
 * 
 * US Government Users Restricted Rights - Use, duplication or
 * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 ***********************************************
 */
package com.ibm.websphere.icp.telecom.reference.incidentproblemanagement.cbs.service;

import java.util.logging.Logger;

import commonj.sdo.DataObject;

import com.ibm.websphere.fabric.industry.support.util.IndustrySupportUtil;
import com.ibm.websphere.icp.telecom.reference.incidentproblemanagement.cbs.util.IConstants;
import com.ibm.websphere.sca.ServiceManager;

public class ExecuteTestImpl {
	
	private Logger logger = Logger.getLogger(this.getClass().getName()); 
	
	/**
	 * Default constructor.
	 */
	public ExecuteTestImpl() {
		super();
	}

	/**
	 * Return a reference to the component service instance for this implementation
	 * class.  This method should be used when passing this service to a partner reference
	 * or if you want to invoke this component service asynchronously.    
	 *
	 * @generated (com.ibm.wbit.java)
	 */
	@SuppressWarnings("unused")
	private Object getMyService() {
		return (Object) ServiceManager.INSTANCE.locateService("self");
	}

	/**
	 * Method generated to support implementation of operation "executeResourceDiagnosticTest" defined for WSDL port type 
	 * named "ExecuteResourceDiagnosticTestPT".
	 * 
	 * The presence of commonj.sdo.DataObject as the return type and/or as a parameter 
	 * type conveys that it is a complex type. Please refer to the WSDL Definition for more information 
	 * on the type of input, output and fault(s).
	 */
	public DataObject executeResourceDiagnosticTest(DataObject aResourceOrderMessage) {

		logger.info(this.getClass().getName() + " - Enter executeResourceDiagnosticTest"); 
		
		DataObject executeTestResponseMessage = IndustrySupportUtil.createDO(IConstants.NS_RESOURCE_ORDER_MESSAGE, IConstants.DO_RESOURCE_ORDER_MESSAGE);  

		DataObject header = (DataObject) aResourceOrderMessage.getDataObject(IConstants.DO_HEADER_ELEMENT); 
		if (header == null) { 
		   header = IndustrySupportUtil.createDO(IConstants.NS_HEADER, IConstants.DO_HEADER); 
		}
		header.setString(IConstants.MSGTYPE, IConstants.RESPONSE);
		executeTestResponseMessage.setDataObject(IConstants.DO_HEADER_ELEMENT, header); 
		
		String sExecuteResourceTestStatus = IConstants.VALID_INCIDENT; 
		
		DataObject executeTestRequest = aResourceOrderMessage.getDataObject(IConstants.DO_RESOURCE_ORDER_ELEMENT); 
		String sExecuteResourceTestQuery = executeTestRequest.getString(IConstants.ATTR_EXECUTE_RESOURCE_TEST_QUERY); 
		if ((sExecuteResourceTestQuery != null) && (sExecuteResourceTestQuery.startsWith("Test-Invalid"))) {
	       sExecuteResourceTestStatus = IConstants.INVALID_INCIDENT;  
		}
		
		DataObject executeTestResponse = IndustrySupportUtil.createDO(IConstants.NS_RESOURCE_ORDER, IConstants.DO_RESOURCE_ORDER);
		
        executeTestResponse.setString(IConstants.ATTR_EXECUTE_RESOURCE_TEST_STATUS, sExecuteResourceTestStatus); 
		executeTestResponseMessage.setDataObject(IConstants.DO_RESOURCE_ORDER_ELEMENT, executeTestResponse); 
		
		logger.info("Execute Resource Diagnostic Test Query: " + executeTestRequest.getString(IConstants.ATTR_EXECUTE_RESOURCE_TEST_QUERY)); 
		logger.info("Execute Resource Diagnostic Test Result: " + executeTestResponse.getString(IConstants.ATTR_EXECUTE_RESOURCE_TEST_STATUS)); 
		
		logger.info(this.getClass().getName() + " - Exit executeResourceDiagnosticTest"); 
		return executeTestResponseMessage;
	}

}