/***********************************************
 * Licensed Materials - Property of IBM
 * 
 * 5724-R31, 5655-S30
 *
 * (C) Copyright IBM Corp. 2010, 2011 All Rights Reserved.
 * 
 * US Government Users Restricted Rights - Use, duplication or
 * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 ***********************************************
 */
package com.ibm.websphere.icp.telecom.reference.incidentproblemanagement.cbs.service;

import java.io.IOException;
import java.io.InputStream;
import java.util.ArrayList;
import java.util.List;
import java.util.Properties;
import java.util.logging.Level;
import java.util.logging.Logger;

import commonj.sdo.DataObject;

import com.ibm.websphere.fabric.industry.support.util.IndustrySupportUtil;
import com.ibm.websphere.icp.telecom.reference.incidentproblemanagement.cbs.util.IConstants;
import com.ibm.websphere.sca.ServiceManager;

public class GetCustomerOldProblemTicketImpl {
	
	private Logger logger = Logger.getLogger(this.getClass().getName()); 
	
	/**
	 * Default constructor.
	 */
	public GetCustomerOldProblemTicketImpl() {
		super();
	}

	/**
	 * Return a reference to the component service instance for this implementation
	 * class.  This method should be used when passing this service to a partner reference
	 * or if you want to invoke this component service asynchronously.    
	 *
	 * @generated (com.ibm.wbit.java)
	 */
	@SuppressWarnings("unused")
	private Object getMyService() {
		return (Object) ServiceManager.INSTANCE.locateService("self");
	}

	/**
	 * Method generated to support implementation of operation "findTroubleTicket" defined for WSDL port type 
	 * named "FindTroubleTicketPT".
	 * 
	 * The presence of commonj.sdo.DataObject as the return type and/or as a parameter 
	 * type conveys that it is a complex type. Please refer to the WSDL Definition for more information 
	 * on the type of input, output and fault(s).
	 */
	public DataObject findTroubleTicket(DataObject aTroubleTicketMessage) {
		
		logger.info(this.getClass().getName() + " - Enter findTroubleTicket"); 

		DataObject header = (DataObject) aTroubleTicketMessage.getDataObject(IConstants.DO_HEADER_ELEMENT); 
		DataObject customerProblemRequest = (DataObject) aTroubleTicketMessage.getDataObject(IConstants.DO_TROUBLE_TICKET_ELEMENT);   

		String sCustomerName = customerProblemRequest.getString(IConstants.ATTR_CUSTOMER_NAME);
		logger.info("Customer Name: " + sCustomerName); 
		
		String sTroubleType = customerProblemRequest.getString(IConstants.ATTR_TROUBLE_TYPE);  
		logger.info("Trouble Type: " + sTroubleType); 

		
		DataObject customerProblemResponse = IndustrySupportUtil.createDO(IConstants.NS_TROUBLE_TICKET, IConstants.DO_TROUBLE_TICKET);  

		String sCustomerProblemID = getOldCustomerProblemID(sCustomerName, sTroubleType);
		if (sCustomerProblemID == null) { 
		   customerProblemResponse.setString(IConstants.ATTR_CUSTOMER_PROBLEM_ID, IConstants.OLD_CUSTOMER_PROBLEM_NOT_FOUND); 
		} else { 
			customerProblemResponse.setString(IConstants.ATTR_CUSTOMER_PROBLEM_ID, sCustomerProblemID);  
		}
		
		DataObject customerProblemResponseMessage = IndustrySupportUtil.createDO(IConstants.NS_TROUBLE_TICKET_COLL_MESSAGE, IConstants.DO_TROUBLE_TICKET_COLL_MESSAGE);  

		header.setString(IConstants.MSGTYPE, IConstants.RESPONSE);
		customerProblemResponseMessage.setDataObject(IConstants.DO_HEADER_ELEMENT, header); 

		List<DataObject> aList = new ArrayList<DataObject>();
		aList.add(customerProblemResponse); 
		
		customerProblemResponseMessage.setList(IConstants.DO_TROUBLE_TICKET_ELEMENT, aList);  

		logger.info("Old Customer Problem ID: " + customerProblemResponse.getString(IConstants.ATTR_CUSTOMER_PROBLEM_ID)); 
		
		logger.info(this.getClass().getName() + " - Exit findTroubleTicket"); 
		return customerProblemResponseMessage;	
	}
	
	private String getOldCustomerProblemID(String customerName, String troubleType) {
		
		logger.entering(this.getClass().getName(), "getOldCustomerProblemID", "Customer Name: " + customerName + ", Trouble Type: " + troubleType);   
		
		InputStream file = null;
		String customerProblemID = null;  

		Properties properties = new Properties();
		try {
			file = getClass().getResourceAsStream(IConstants.OLD_CUSTOMER_PROBLEM_PROPERTIES_FILE);  
			properties.load(file);
			
			customerName = customerName.replace(" ", "-"); 
			troubleType = troubleType.replace(" ", "-"); 
			customerProblemID = properties.getProperty(customerName + "@" + troubleType);
			
		} catch (IOException e) {
			logger.log(Level.SEVERE, "Error Reading Properties File: " + IConstants.OLD_CUSTOMER_PROBLEM_PROPERTIES_FILE, e);
		} finally {
			
			try {
				if (file != null) {
					file.close();
				}
			} catch (IOException e) {}
		}
		
		logger.exiting(this.getClass().getName(), "getOldCustomerProblemID", "Customer Name: " + customerName + ", Trouble Type: " + troubleType);   
		return customerProblemID;
	}	
}