/***********************************************
 * Licensed Materials - Property of IBM
 * 
 * 5724-R31, 5655-S30
 *
 * (C) Copyright IBM Corp. 2010, 2011 All Rights Reserved.
 * 
 * US Government Users Restricted Rights - Use, duplication or
 * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 ***********************************************
 */
package com.ibm.websphere.icp.telecom.reference.incidentproblemanagement.cbs.service;

import java.io.IOException;
import java.io.InputStream;
import java.util.Properties;
import java.util.logging.Level;
import java.util.logging.Logger;

import commonj.sdo.DataObject;

import com.ibm.websphere.fabric.industry.support.util.IndustrySupportUtil;
import com.ibm.websphere.icp.telecom.reference.incidentproblemanagement.cbs.util.IConstants;
import com.ibm.websphere.sca.ServiceManager;

public class GetProductsUsedByCustomerImpl {
	
	private Logger logger = Logger.getLogger(this.getClass().getName()); 
	
	/**
	 * Default constructor.
	 */
	public GetProductsUsedByCustomerImpl() {
		super();
	}

	/**
	 * Return a reference to the component service instance for this implementation
	 * class.  This method should be used when passing this service to a partner reference
	 * or if you want to invoke this component service asynchronously.    
	 *
	 * @generated (com.ibm.wbit.java)
	 */
	@SuppressWarnings("unused")
	private Object getMyService() {
		return (Object) ServiceManager.INSTANCE.locateService("self");
	}

	/**
	 * Method generated to support implementation of operation "retrieveCustomerProductConfiguration" defined for WSDL port type 
	 * named "RetrieveCustomerProductConfigurationPT".
	 * 
	 * The presence of commonj.sdo.DataObject as the return type and/or as a parameter 
	 * type conveys that it is a complex type. Please refer to the WSDL Definition for more information 
	 * on the type of input, output and fault(s).
	 */
	public DataObject retrieveCustomerProductConfiguration(DataObject aLookupRequestMessage) {

		logger.info(this.getClass().getName() + " - Enter retrieveCustomerProductConfiguration"); 
		
		DataObject customerProductConfigResponseMessage = IndustrySupportUtil.createDO(IConstants.NS_CUSTOMER_PRODCUT_CONFIG_MESSAGE, IConstants.DO_CUSTOMER_PRODCUT_CONFIG_MESSAGE);  

		DataObject header = (DataObject) aLookupRequestMessage.getDataObject(IConstants.DO_HEADER_ELEMENT); 
		if (header == null) { 
		   header = IndustrySupportUtil.createDO(IConstants.NS_HEADER, IConstants.DO_HEADER); 
		}
		header.setString(IConstants.MSGTYPE, IConstants.RESPONSE);
		customerProductConfigResponseMessage.setDataObject(IConstants.DO_HEADER_ELEMENT, header); 
		
		String sCustomerName = aLookupRequestMessage.getString(IConstants.ATTR_CUSTOMER_NAME_IN_LOOKUP_REQUEST); 
		
		DataObject customerProductConfigResponse = IndustrySupportUtil.createDO(IConstants.NS_CUSTOMER_PRODCUT_CONFIG, IConstants.DO_CUSTOMER_PRODCUT_CONFIG);
		
		String sProduct = getProductsUsedByCustomer(sCustomerName); 
		customerProductConfigResponse.setString(IConstants.ATTR_PRODUCT_USED_BY_CUSTOMER, sProduct); 
		customerProductConfigResponseMessage.setDataObject(IConstants.DO_CUSTOMER_PRODUCT_CONFIG_ELEMENT, customerProductConfigResponse); 
		
		logger.info("Products Used By Customer: " + customerProductConfigResponse.getString(IConstants.ATTR_PRODUCT_USED_BY_CUSTOMER)); 
		
		logger.info(this.getClass().getName() + " - Exit retrieveCustomerProductConfiguration"); 
		return customerProductConfigResponseMessage;
	}

	private String getProductsUsedByCustomer(String customerName) { 
			
		logger.entering(this.getClass().getName(), "getProductsUsedByCustomer", "Customer Name: " + customerName);   
		
		InputStream file = null;
		String products = null;  

		Properties properties = new Properties();
		try {
			file = getClass().getResourceAsStream(IConstants.PRODUCTS_USED_BY_CUSTOMER_PROPERTIES_FILE);  
			properties.load(file);
		
			customerName = customerName.replace(" ", "-"); 
			products = properties.getProperty(customerName);
			
		} catch (IOException e) {
			logger.log(Level.SEVERE, "Error Reading Properties File: " + IConstants.PRODUCTS_USED_BY_CUSTOMER_PROPERTIES_FILE, e);
		} finally {
			
			try {
				if (file != null) {
					file.close();
				}
			} catch (IOException e) {}
		}
		
		logger.exiting(this.getClass().getName(), "getProductsUsedByCustomer", "Customer Name: " + customerName);   
		return products;
	}	
}