/***********************************************
 * Licensed Materials - Property of IBM
 * 
 * 5724-R31, 5655-S30
 * 
 * (C) Copyright IBM Corp. 2010 All Rights Reserved.
 * 
 * US Government Users Restricted Rights - Use, duplication or
 * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 ***********************************************
 */
package com.ibm.websphere.icp.telecom.reference.dynamicorderfulfillment;

import java.io.Serializable;
import java.util.Set;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.ManyToOne;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.OneToMany;

import com.ibm.websphere.icp.telecom.db.entities.TelecomBaseObject;

@Entity
@NamedQueries( {
		@NamedQuery(name = "findCustomerById", query = "SELECT OBJECT(cust) FROM Customermaster cust WHERE cust.id = :id"),
		@NamedQuery(name = "findCustomerByInfo", query = "SELECT OBJECT(cust) FROM Customermaster cust WHERE cust.firstName = :firstName or cust.lastName= :lastName or cust.middleName = :middleName or cust.mobilePhoneNumber =:mobilePhoneNumber or cust.fixedLinePhoneNumber =:fixedLinePhoneNumber or cust.email =:email"),
		@NamedQuery(name = "findCustomerByName", query = "SELECT OBJECT(cust) FROM Customermaster cust WHERE cust.firstName = :firstName or cust.lastName= :lastName or cust.mobilePhoneNumber =:mobilePhoneNumber or cust.fixedLinePhoneNumber =:fixedLinePhoneNumber or cust.email =:email"),
		@NamedQuery(name = "findCustomerByAccountId", query = "SELECT OBJECT(cust) FROM Customermaster cust, Customeraccount cust_acc WHERE cust_acc.id= :id"),
		@NamedQuery(name = "findCustomerByOrderId", query = "SELECT OBJECT(ser_ord) FROM Serviceorder ser_ord WHERE ser_ord.id= :id"),
		@NamedQuery(name = "findAccountByCustomerId", query = "SELECT OBJECT(cust_acc) FROM Customermaster cust, Customeraccount cust_acc WHERE cust.id= :id") })
public class Customermaster extends TelecomBaseObject implements Serializable {

	@Column(name = "FIRST_NAME")
	private String firstName;

	@Column(name = "MIDDLE_NAME")
	private String middleName;

	@Column(name = "LAST_NAME")
	private String lastName;

	private String title;

	private String country;

	private String state;

	private String city;

	private String email;

	@Column(name = "MOBILE_PHONE_NUMBER")
	private String mobilePhoneNumber;

	@Column(name = "FIXED_LINE_PHONE_NUMBER")
	private String fixedLinePhoneNumber;

	@Column(name = "STREET_NR")
	private String streetNr;

	@Column(name = "STREET_NAME")
	private String streetName;

	@Column(name = "STREET_TYPE")
	private String streetType;

	@Column(name = "UNIT_TYPE")
	private String unitType;

	@Column(name = "UNIT_NR")
	private int unitNr;

	@Column(name = "POST_CODE")
	private String postCode;
	
	@Column(name = "PREFERREDLANGUAGE")
	private String preferredLangauge;

	@ManyToOne
	private Customeraccount account;

	@OneToMany(mappedBy = "customerMaster")
	private Set<Serviceorder> serviceorderCollection;

	@OneToMany(mappedBy = "customermaster")
	private Set<Productorder> productorderCollection;

	@OneToMany(mappedBy = "customermaster")
	private Set<Resourceorder> resourceorderCollection;

	private static final long serialVersionUID = 1L;

	public Customermaster() {
		super();
	}

	public String getFirstName() {
		return this.firstName;
	}

	public void setFirstName(String firstName) {
		this.firstName = firstName;
	}

	public String getMiddleName() {
		return this.middleName;
	}

	public void setMiddleName(String middleName) {
		this.middleName = middleName;
	}

	public String getLastName() {
		return this.lastName;
	}

	public void setLastName(String lastName) {
		this.lastName = lastName;
	}

	public String getTitle() {
		return this.title;
	}

	public void setTitle(String title) {
		this.title = title;
	}

	public String getCountry() {
		return this.country;
	}

	public void setCountry(String country) {
		this.country = country;
	}

	public String getState() {
		return this.state;
	}

	public void setState(String state) {
		this.state = state;
	}

	public String getCity() {
		return this.city;
	}

	public void setCity(String city) {
		this.city = city;
	}

	public String getEmail() {
		return this.email;
	}

	public void setEmail(String email) {
		this.email = email;
	}

	public String getMobilePhoneNumber() {
		return this.mobilePhoneNumber;
	}

	public void setMobilePhoneNumber(String mobilePhoneNumber) {
		this.mobilePhoneNumber = mobilePhoneNumber;
	}

	public String getFixedLinePhoneNumber() {
		return this.fixedLinePhoneNumber;
	}

	public void setFixedLinePhoneNumber(String fixedLinePhoneNumber) {
		this.fixedLinePhoneNumber = fixedLinePhoneNumber;
	}

	public String getStreetNr() {
		return this.streetNr;
	}

	public void setStreetNr(String streetNr) {
		this.streetNr = streetNr;
	}

	public String getStreetName() {
		return this.streetName;
	}

	public void setStreetName(String streetName) {
		this.streetName = streetName;
	}

	public String getStreetType() {
		return this.streetType;
	}

	public void setStreetType(String streetType) {
		this.streetType = streetType;
	}

	public String getUnitType() {
		return this.unitType;
	}

	public void setUnitType(String unitType) {
		this.unitType = unitType;
	}

	public int getUnitNr() {
		return this.unitNr;
	}

	public void setUnitNr(int unitNr) {
		this.unitNr = unitNr;
	}

	public String getPostCode() {
		return this.postCode;
	}

	public void setPostCode(String postCode) {
		this.postCode = postCode;
	}
	
	public String getPreferredLangauge() {
		return this.preferredLangauge;
	}

	public void setPreferredLangauge(String preferredLangauge) {
		this.preferredLangauge = preferredLangauge;
	}
	public Customeraccount getAccount() {
		return this.account;
	}

	public void setAccount(Customeraccount account) {
		this.account = account;
	}

	public Set<Serviceorder> getServiceorderCollection() {
		return this.serviceorderCollection;
	}

	public void setServiceorderCollection(
			Set<Serviceorder> serviceorderCollection) {
		this.serviceorderCollection = serviceorderCollection;
	}

	public Set<Productorder> getProductorderCollection() {
		return this.productorderCollection;
	}

	public void setProductorderCollection(
			Set<Productorder> productorderCollection) {
		this.productorderCollection = productorderCollection;
	}

	public Set<Resourceorder> getResourceorderCollection() {
		return this.resourceorderCollection;
	}

	public void setResourceorderCollection(
			Set<Resourceorder> resourceorderCollection) {
		this.resourceorderCollection = resourceorderCollection;
	}

	public String toString() {
		return "FirstName : " + this.firstName + " Last Name : "
				+ this.lastName;

	}
}
