/***********************************************
 * Licensed Materials - Property of IBM
 * 
 * 5724-R31, 5655-S30
 * 
 * (C) Copyright IBM Corp. 2010 All Rights Reserved.
 * 
 * US Government Users Restricted Rights - Use, duplication or
 * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 ***********************************************
 */
package com.ibm.websphere.icp.telecom.reference.dynamicorderfulfillment.mock;

import java.util.HashMap;
import java.util.Properties;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.ibm.websphere.fabric.industry.support.util.IndustrySupportUtil;
import com.ibm.websphere.icp.industry.db.manager.IWicpDBFactoryConstants;
import com.ibm.websphere.icp.industry.db.manager.IWicpDBManager;
import com.ibm.websphere.icp.industry.db.manager.WicpDBFactory;
import com.ibm.websphere.icp.telecom.reference.dynamicorderfulfillment.Customeraccount;
import com.ibm.websphere.icp.telecom.reference.dynamicorderfulfillment.util.IConstants;
import com.ibm.websphere.icp.telecom.reference.dynamicorderfulfillment.util.TelecomSupportUtil;
import com.ibm.websphere.sca.ServiceManager;
import commonj.sdo.DataObject;

public class AuthorizeCreditImpl {
	/**
	 * Default constructor.
	 */
	public AuthorizeCreditImpl() {
		super();
	}

	private static final Log log = LogFactory.getLog(AuthorizeCreditImpl.class);

	/**
	 * Return a reference to the component service instance for this
	 * implementation class. This method should be used when passing this
	 * service to a partner reference or if you want to invoke this component
	 * service asynchronously.
	 * 
	 * @generated (com.ibm.wbit.java)
	 */
	@SuppressWarnings("unused")
	private Object getMyService() {
		return (Object) ServiceManager.INSTANCE.locateService("self");
	}

	/**
	 * Method generated to support implementation of operation "authorizeCredit"
	 * defined for WSDL port type named "AuthorizeCreditPT".
	 * 
	 * The presence of commonj.sdo.DataObject as the return type and/or as a
	 * parameter type conveys that it is a complex type. Please refer to the
	 * WSDL Definition for more information on the type of input, output and
	 * fault(s).
	 */
	public DataObject authorizeCredit(DataObject aCustomerOrderMessage) {

		DataObject rsCustomerOrderMessage = null;

		DataObject header = null;
		DataObject party = null;

		try {
			rsCustomerOrderMessage = IndustrySupportUtil
					.createDO(
							"http://www.ibm.com/xmlns/prod/websphere/fabric/2009/12/telecom/operations/fulfillment/schema/CustomerOrderMessage",
							"CustomerOrderMessage");
			// For
			header = aCustomerOrderMessage.getDataObject(IConstants.DO_HEADER);

			DataObject customerOrder = aCustomerOrderMessage
					.getDataObject("customerOrder");
			int customerId = Integer.valueOf(customerOrder.getString("Id"));
			/**
			 * Create the Map to fetch Customer from Db
			 */
			HashMap<String, Object> mapParams = new HashMap<String, Object>();
			mapParams.put("id", Integer.valueOf(customerId));

			/**
			 * get the DbFactory and persist data
			 */
			Properties dbProperties = new Properties();
			dbProperties.setProperty(IWicpDBFactoryConstants.TYPE, "JPA");
			dbProperties.setProperty(
					IWicpDBFactoryConstants.PERSISTENCE_UNIT_NAME,
					IConstants.DB_ACCESS);
			IWicpDBManager wicpDbManager = WicpDBFactory
					.getDBManager(dbProperties);

			Customeraccount customerAccount = new Customeraccount();
			customerAccount = (Customeraccount) wicpDbManager
					.executeNamedQuery("findAccountByCustomerId", mapParams)
					.get(0);

			// Setting Header
			if (header != null) {
				header.setString(IConstants.MSGTYPE, IConstants.RESPONSE);
				rsCustomerOrderMessage.set(IConstants.DO_HEADER, header);
			}
			DataObject rsCustomerOrder = rsCustomerOrderMessage
					.createDataObject("customerOrder");
			rsCustomerOrder.setString("Id", String.valueOf(customerId));
			/**
			 * Set the credit score in the name
			 */
			if (Integer.parseInt((customerAccount.getCreditScore())) > 500) {
				rsCustomerOrder.setString("Name", IConstants.SERVICE_APPROVED);	
			} else {
				rsCustomerOrder.setString("Name", IConstants.SERVICE_DECLINED);
			}
			
			
			rsCustomerOrder.setString("InteractionStatus", "Success");
		} catch (Exception e) {
			log.info("Error in DetermineCreditRatingImpl", e);
			header = rsCustomerOrderMessage
					.createDataObject(IConstants.DO_HEADER);
			header = TelecomSupportUtil.createHeader(header, e);
		}
		return rsCustomerOrderMessage;
	}
}
