/***********************************************
 * Licensed Materials - Property of IBM
 * 
 * 5724-R31, 5655-S30
 * 
 * (C) Copyright IBM Corp. 2010 All Rights Reserved.
 * 
 * US Government Users Restricted Rights - Use, duplication or
 * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 ***********************************************
 */
package com.ibm.websphere.icp.telecom.reference.dynamicorderfulfillment.mock;

import java.io.IOException;
import java.io.InputStream;
import java.util.List;
import java.util.Properties;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.ibm.websphere.fabric.industry.support.util.IndustrySupportUtil;
import com.ibm.websphere.icp.telecom.reference.dynamicorderfulfillment.util.IConstants;
import com.ibm.websphere.icp.telecom.reference.dynamicorderfulfillment.util.TelecomSupportUtil;
import com.ibm.websphere.sca.ServiceManager;
import commonj.sdo.DataObject;

/**
 * @author nikunj.panchal
 * 
 */

public class CheckGenericTechnicalAvailabilityImpl {
	/**
	 * Default constructor.
	 */

	private static final Log log = LogFactory
			.getLog(CheckGenericTechnicalAvailabilityImpl.class);

	public CheckGenericTechnicalAvailabilityImpl() {
		super();
	}

	/**
	 * Return a reference to the component service instance for this
	 * implementation class. This method should be used when passing this
	 * service to a partner reference or if you want to invoke this component
	 * service asynchronously.
	 * 
	 * @generated (com.ibm.wbit.java)
	 */
	@SuppressWarnings("unused")
	private Object getMyService() {
		return (Object) ServiceManager.INSTANCE.locateService("self");
	}

	/**
	 * Method generated to support implementation of operation
	 * "checkGenericTechnicalAvailability" defined for WSDL port type named
	 * "CheckGenericTechnicalAvailabilityPT".
	 * 
	 * The presence of commonj.sdo.DataObject as the return type and/or as a
	 * parameter type conveys that it is a complex type. Please refer to the
	 * WSDL Definition for more information on the type of input, output and
	 * fault(s).
	 */
	public DataObject checkGenericTechnicalAvailability(
			DataObject aResourceOrderMessage) {
		DataObject resourceOrderResponseMessage = null;
		DataObject header = null;
		DataObject result = null;
		try {
			resourceOrderResponseMessage = IndustrySupportUtil.createDO(
					IConstants.NS_RESOURCEORDERMESSAGE,
					IConstants.DO_RESOURCEORDERMESSAGE);

			// For header
			header = aResourceOrderMessage.getDataObject(IConstants.DO_HEADER);

			// For service
			DataObject resource = null;
			String resourceOrderId = "";
			DataObject resourceOrderDO = aResourceOrderMessage
					.getDataObject(IConstants.DO_NAME_RESOURCEORDER);
			List resourceOrderItemList = resourceOrderDO
					.getList(IConstants.DO_RESOURCEORDERITEM);
			if (resourceOrderItemList.size() > 0) {

				DataObject reqResourceOrderItem = (DataObject) resourceOrderItemList
						.get(0);
				resource = reqResourceOrderItem.getDataObject("Resource");

				// Response creation
				// Setting Service

				if (resource != null) {
					resourceOrderId = resource.getString(IConstants.DO_ID);
					resourceOrderId = resourceOrderId.replace(" ", "");

				}
				String desc = getDescripiton(resourceOrderId);
				DataObject resourceOrder = resourceOrderResponseMessage
						.createDataObject(IConstants.DO_NAME_RESOURCEORDER);
				if (desc == null) {
					resourceOrder.setString("InteractionStatus", "Unavailable");
				} else {
					resourceOrder.setString("InteractionStatus", "Success");
				}

				DataObject resourceOrderItem = IndustrySupportUtil.createDO(
						IConstants.NS_RESOURCEORDER,
						IConstants.DO_RESOURCEORDERITEM);
				resourceOrderItem.createDataObject(IConstants.DO_RESOURCE)
						.setString(IConstants.DO_NAME_SMALL, desc);
				resourceOrder.getList(IConstants.DO_RESOURCEORDERITEM).add(
						resourceOrderItem);

				// Setting Header
				if (header != null) {
					header.setString(IConstants.MSGTYPE, IConstants.RESPONSE);

				}
				resourceOrderResponseMessage.set(IConstants.DO_HEADER, header);
			}
		} catch (Exception e) {

			header = resourceOrderResponseMessage
					.createDataObject(IConstants.DO_HEADER);
			header = TelecomSupportUtil.createHeader(header, e);
			resourceOrderResponseMessage.set(IConstants.DO_HEADER, header);
			DataObject resourceOrder = resourceOrderResponseMessage
					.createDataObject(IConstants.DO_NAME_RESOURCEORDER);
			resourceOrder.setString(IConstants.ERRORCODE,
					IConstants.DEFAULT_ERRORCODE_VALUE);
			resourceOrder
					.setString(IConstants.ERRORDESCRIPTION, e.getMessage());

			// e.printStackTrace();
		}
		return resourceOrderResponseMessage;
	}

	/**
	 * Method searches given serviceId in the properties file and returns
	 * deescription for it. if serviceId is not found, it returns null
	 */
	private String getDescripiton(String resourceOrderId) {
		String desc = null;

		InputStream file = null;
		Properties properties = new Properties();
		try {
			file = CheckGenericTechnicalAvailabilityImpl.class
					.getResourceAsStream(IConstants.CHECKTECHNICALAVAILABILITYPROPERTIES);
			properties.load(file);
			desc = (String) properties.get(resourceOrderId);

		} catch (IOException e) {
			log.error("Error reading properties file", e);
		} finally {
			try {
				if (file != null) {
					file.close();
				}
			} catch (IOException e) {
				log.error("Error while closing the file", e);
			}
		}
		return desc;
	}

}
