/***********************************************
 * Licensed Materials - Property of IBM
 * 
 * 5724-R31, 5655-S30
 * 
 * (C) Copyright IBM Corp. 2010 All Rights Reserved.
 * 
 * US Government Users Restricted Rights - Use, duplication or
 * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 ***********************************************
 */
package com.ibm.websphere.icp.telecom.reference.dynamicorderfulfillment.mock;

import java.io.IOException;
import java.io.InputStream;
import java.util.List;
import java.util.Properties;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.ibm.websphere.fabric.industry.support.util.IndustrySupportUtil;
import com.ibm.websphere.icp.telecom.reference.dynamicorderfulfillment.util.IConstants;
import com.ibm.websphere.icp.telecom.reference.dynamicorderfulfillment.util.TelecomSupportUtil;
import com.ibm.websphere.sca.ServiceManager;
import commonj.sdo.DataObject;

public class CheckTechnicalAvailabilityImpl {
	/**
	 * Default constructor.
	 */

	private static final Log log = LogFactory
			.getLog(CheckTechnicalAvailabilityImpl.class);

	public CheckTechnicalAvailabilityImpl() {
		super();
	}

	/**
	 * Return a reference to the component service instance for this
	 * implementation class. This method should be used when passing this
	 * service to a partner reference or if you want to invoke this component
	 * service asynchronously.
	 * 
	 * @generated (com.ibm.wbit.java)
	 */
	@SuppressWarnings("unused")
	private Object getMyService() {
		return (Object) ServiceManager.INSTANCE.locateService("self");
	}

	/**
	 * Method generated to support implementation of operation
	 * "checkTechnicalAvailability" defined for WSDL port type named
	 * "CheckTechnicalAvailabilityPT".
	 * 
	 * The presence of commonj.sdo.DataObject as the return type and/or as a
	 * parameter type conveys that it is a complex type. Please refer to the
	 * WSDL Definition for more information on the type of input, output and
	 * fault(s).
	 */
	public DataObject checkTechnicalAvailability(DataObject aServiceOrderMessage) {
		DataObject serviceOrderResponseMessage = null;
		DataObject header = null;
		DataObject result = null;
		try {
			serviceOrderResponseMessage = IndustrySupportUtil.createDO(
					IConstants.NS_SERVICEORDERMESSAGE,
					IConstants.DO_SERVICEORDERMESSAGE);

			// For header
			header = aServiceOrderMessage.getDataObject(IConstants.DO_HEADER);

			// For service
			DataObject service = null;
			String serviceOrderId = "";
			DataObject serviceOrderDO = aServiceOrderMessage
					.getDataObject(IConstants.DO_NAME_SERVICEORDER);
			List serviceOrderItemList = serviceOrderDO
					.getList(IConstants.DO_SERVICEORDERITEM);
			if (serviceOrderItemList.size() > 0) {
				DataObject reqServiceOrderItem = (DataObject) serviceOrderItemList
						.get(0);
				service = reqServiceOrderItem.getDataObject("Service");

				// Response creation
				// Setting Service

				if (service != null) {
					serviceOrderId = service.getString(IConstants.DO_ID);
					serviceOrderId = serviceOrderId.replace(" ", "");
				}

				String desc = getDescripiton(serviceOrderId);
				DataObject serviceOrder = serviceOrderResponseMessage
						.createDataObject(IConstants.DO_NAME_SERVICEORDER);
				if (desc == null) {
					serviceOrder.setString("InteractionStatus", "Unavailable");
				} else {
					serviceOrder.setString("InteractionStatus", "Success");
				}

				DataObject serviceOrderItem = IndustrySupportUtil.createDO(
						IConstants.NS_SERVICEORDER,
						IConstants.DO_SERVICEORDERITEM);
				serviceOrderItem.createDataObject(IConstants.DO_SERVICE)
						.setString(IConstants.DO_NAME_SMALL, desc);
				serviceOrder.getList(IConstants.DO_SERVICEORDERITEM).add(
						serviceOrderItem);

				// Setting Header
				if (header != null) {
					header.setString(IConstants.MSGTYPE, IConstants.RESPONSE);

				}
				serviceOrderResponseMessage.set(IConstants.DO_HEADER, header);
			}
		} catch (Exception e) {

			header = serviceOrderResponseMessage
					.createDataObject(IConstants.DO_HEADER);
			header = TelecomSupportUtil.createHeader(header, e);
			serviceOrderResponseMessage.set(IConstants.DO_HEADER, header);
			DataObject serviceOrder = serviceOrderResponseMessage
					.createDataObject(IConstants.DO_NAME_SERVICEORDER);
			serviceOrder.setString(IConstants.ERRORCODE,
					IConstants.DEFAULT_ERRORCODE_VALUE);
			serviceOrder.setString(IConstants.ERRORDESCRIPTION, e.getMessage());

			// e.printStackTrace();
		}
		return serviceOrderResponseMessage;
	}

	/**
	 * Method searches given serviceId in the properties file and returns
	 * deescription for it. if serviceId is not found, it returns null
	 */
	private String getDescripiton(String serviceOrderId) {
		String desc = null;

		InputStream file = null;
		Properties properties = new Properties();
		try {
			file = CheckTechnicalAvailabilityImpl.class
					.getResourceAsStream(IConstants.CHECKTECHNICALAVAILABILITYPROPERTIES);
			// System.out.println("File : " + file);
			properties.load(file);
			desc = (String) properties.get(serviceOrderId);
		} catch (IOException e) {
			log.error("Error reading properties file", e);
		} finally {
			try {
				if (file != null) {
					file.close();
				}
			} catch (IOException e) {
				log.error("Error while closing the file", e);
			}
		}
		return desc;
	}

}
