/***********************************************
 * Licensed Materials - Property of IBM
 * 
 * 5724-R31, 5655-S30
 * 
 * (C) Copyright IBM Corp. 2010 All Rights Reserved.
 * 
 * US Government Users Restricted Rights - Use, duplication or
 * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 ***********************************************
 */
package com.ibm.websphere.icp.telecom.reference.dynamicorderfulfillment.mock;

import java.util.ArrayList;
import java.util.List;

import com.ibm.websphere.fabric.industry.support.util.IndustrySupportUtil;
import com.ibm.websphere.icp.telecom.reference.dynamicorderfulfillment.util.IConstants;
import com.ibm.websphere.icp.telecom.reference.dynamicorderfulfillment.util.TelecomSupportUtil;
import com.ibm.websphere.sca.ServiceManager;
import commonj.sdo.DataObject;

/**
 * @author nikunj.panchal
 * 
 */
public class DecomposeProductOrderImpl {
	/**
	 * Default constructor.
	 */
	public DecomposeProductOrderImpl() {
		super();
	}

	/**
	 * Return a reference to the component service instance for this
	 * implementation class. This method should be used when passing this
	 * service to a partner reference or if you want to invoke this component
	 * service asynchronously.
	 * 
	 * @generated (com.ibm.wbit.java)
	 */
	@SuppressWarnings("unused")
	private Object getMyService() {
		return (Object) ServiceManager.INSTANCE.locateService("self");
	}

	/**
	 * Method generated to support implementation of operation
	 * "decomposeProductOrder" defined for WSDL port type named
	 * "DecomposeProductOrderPT".
	 * 
	 * The presence of commonj.sdo.DataObject as the return type and/or as a
	 * parameter type conveys that it is a complex type. Please refer to the
	 * WSDL Definition for more information on the type of input, output and
	 * fault(s).
	 */
	public DataObject decomposeProductOrder(DataObject aProductOrderMessage) {
		DataObject orderDecompositionResponseMessage = null;
		DataObject header = null;
		String serviceId = "";
		String resourceId = ""; // Product category id is set in this
		// For Product
		DataObject productOrderDO = null;
		DataObject specification = null;
		List resourceOrderItemList = new ArrayList();
		List serviceOrderItemList = new ArrayList();
		List productOrderItemList = new ArrayList();
		try {
			// Response creation
			orderDecompositionResponseMessage = IndustrySupportUtil.createDO(
					IConstants.NS_ORDERDECOMPOSITIONMESSAGE,
					IConstants.DO_ORDERDECOMPOSITIONMESSAGE);
			// Getting details from request
			// For header
			header = aProductOrderMessage.getDataObject(IConstants.DO_HEADER);
			productOrderDO = aProductOrderMessage
					.getDataObject(IConstants.PRODUCTORDER);
			List productOrderItemList1 = productOrderDO
					.getList(IConstants.PRODUCTORDERITEM);

			DataObject productOrderItem = (DataObject) productOrderItemList1
					.get(0);
			DataObject product = productOrderItem
					.getDataObject(IConstants.PRODUCT);

			// Getting ProductId
			if (product != null) {
				serviceId = product.getString(IConstants.DO_NAME);
			}

			specification = productOrderDO.getDataObject("Specification");
			resourceId = specification.getString(IConstants.DO_NAME);

			DataObject resourceOrder = orderDecompositionResponseMessage
					.createDataObject(IConstants.DO_NAME_RESOURCEORDER);
			DataObject serviceOrder = orderDecompositionResponseMessage
					.createDataObject(IConstants.DO_NAME_SERVICEORDER);

			/**
			 * Decompose Resource
			 */

			DataObject resource = IndustrySupportUtil.createDO(
					IConstants.NS_BUSINESSINTERACTIONENTITY,
					IConstants.DO_BUSINESSINTERACTIONENTITY);
			// For ResourceOrder related setting
			if (resourceId != null) {
				String[] resourceIds = getResourcesForProductId(resourceId);
				for (int i = 0; i < resourceIds.length; i++) {
					resource.setString(IConstants.DO_ID, resourceIds[i]);
				}
			}
			DataObject resourceOrderItem = IndustrySupportUtil.createDO(
					IConstants.NS_RESOURCEORDER,
					IConstants.DO_RESOURCEORDERITEM);

			resourceOrderItem.setDataObject(IConstants.DO_RESOURCE, resource);
			resourceOrderItemList.add(resourceOrderItem);
			resourceOrder.setList("ResourceOrderItem", resourceOrderItemList);

			// For ServiceOrder related setting

			/**
			 * Decompose Service
			 */

			DataObject service = IndustrySupportUtil.createDO(
					IConstants.NS_BUSINESSINTERACTIONENTITY,
					IConstants.DO_BUSINESSINTERACTIONENTITY);

			if (serviceId != null) {
				String[] serviceIds = getServicesForProductId(serviceId);
				for (int i = 0; i < serviceIds.length; i++) {
					service.setString(IConstants.DO_ID, serviceIds[i]);
				}
			}
			DataObject serviceOrderItem = IndustrySupportUtil.createDO(
					IConstants.NS_SERVICEORDER, IConstants.DO_SERVICEORDERITEM);
			serviceOrderItem.setDataObject(IConstants.DO_SERVICE, service);
			serviceOrderItemList.add(serviceOrderItem);
			serviceOrder.setList(IConstants.DO_SERVICEORDERITEM,
					serviceOrderItemList);

			// Setting Header
			if (header != null) {
				header.setString(IConstants.MSGTYPE, IConstants.RESPONSE);
				orderDecompositionResponseMessage.set(IConstants.DO_HEADER,
						header);
			}

		} catch (Exception e) {

			header = orderDecompositionResponseMessage
					.createDataObject(IConstants.DO_HEADER);
			header = TelecomSupportUtil.createHeader(header, e);

			e.printStackTrace();
		}

		return orderDecompositionResponseMessage;
	}

	private String[] getServicesForProductId(String productId) {
		return new String[] { productId };
	}

	private String[] getResourcesForProductId(String productId) {
		return new String[] { productId };
	}

}
