/***********************************************
 * Licensed Materials - Property of IBM
 * 
 * 5724-R31, 5655-S30
 * 
 * (C) Copyright IBM Corp. 2010 All Rights Reserved.
 * 
 * US Government Users Restricted Rights - Use, duplication or
 * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 ***********************************************
 */
package com.ibm.websphere.icp.telecom.reference.dynamicorderfulfillment.mock;

import java.io.IOException;
import java.io.InputStream;
import java.util.Properties;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.ibm.websphere.fabric.industry.support.util.IndustrySupportUtil;
import com.ibm.websphere.icp.telecom.reference.dynamicorderfulfillment.util.CustomerNotificationConstants;
import com.ibm.websphere.icp.telecom.reference.dynamicorderfulfillment.util.IConstants;
import com.ibm.websphere.sca.ServiceManager;
import commonj.sdo.DataObject;

public class NotifyCustomerImpl {
	/**
	 * Default constructor.
	 */
	private static final Log log = LogFactory.getLog(NotifyCustomerImpl.class);

	public NotifyCustomerImpl() {
		super();
	}

	/**
	 * Return a reference to the component service instance for this
	 * implementation class. This method should be used when passing this
	 * service to a partner reference or if you want to invoke this component
	 * service asynchronously.
	 * 
	 * @generated (com.ibm.wbit.java)
	 */
	@SuppressWarnings("unused")
	private Object getMyService() {
		return (Object) ServiceManager.INSTANCE.locateService("self");
	}

	/**
	 * Method generated to support implementation of operation
	 * "notifyOrderCompletion" defined for WSDL port type named
	 * "NotifyOrderCompletionPT".
	 * 
	 * The presence of commonj.sdo.DataObject as the return type and/or as a
	 * parameter type conveys that it is a complex type. Please refer to the
	 * WSDL Definition for more information on the type of input, output and
	 * fault(s).
	 */
	public DataObject notifyOrderCompletion(DataObject aCustomerOrderMessage) {
		DataObject responseCustomerOrderMessage = null;
		DataObject customerOrderDO = null;
		try {
			responseCustomerOrderMessage = IndustrySupportUtil
			.createDO(
					"http://www.ibm.com/xmlns/prod/websphere/fabric/2009/12/telecom/operations/fulfillment/schema/CustomerOrderMessage",
					"CustomerOrderMessage");
			customerOrderDO = aCustomerOrderMessage
					.getDataObject("customerOrder");
			
			String desc = getDescripiton(customerOrderDO
					.getString(CustomerNotificationConstants.DESCRIPTION));
			customerOrderDO.setString(
					CustomerNotificationConstants.DESCRIPTION, desc);
			responseCustomerOrderMessage.setDataObject("customerOrder", customerOrderDO);

		} catch (Exception e) {
			log.info(e);
		}

		return responseCustomerOrderMessage;
	}

	private String getDescripiton(String notificationId) {
		String desc = null;

		InputStream file = null;
		Properties properties = new Properties();
		try {
			file = NotifyCustomerImpl.class
					.getResourceAsStream(IConstants.NOTIFICATIONPROPERTIES);
			// System.out.println("File : " + file);
			properties.load(file);
			desc = (String) properties.get(notificationId);

		} catch (IOException e) {
			log.error("Error reading properties file", e);
		} finally {
			try {
				if (file != null) {
					file.close();
				}
			} catch (IOException e) {
				log.error("Error while closing the file", e);
			}
		}
		return desc;
	}
}
