/***********************************************
 * Licensed Materials - Property of IBM
 * 
 * 5724-R31, 5655-S30
 * 
 * (C) Copyright IBM Corp. 2010 All Rights Reserved.
 * 
 * US Government Users Restricted Rights - Use, duplication or
 * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 ***********************************************
 */
package com.ibm.websphere.icp.telecom.reference.dynamicorderfulfillment.mock;

import java.io.IOException;
import java.io.InputStream;
import java.util.ArrayList;
import java.util.List;
import java.util.Properties;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.ibm.websphere.fabric.industry.support.util.IndustrySupportUtil;
import com.ibm.websphere.icp.telecom.reference.dynamicorderfulfillment.util.IConstants;
import com.ibm.websphere.icp.telecom.reference.dynamicorderfulfillment.util.TelecomSupportUtil;
import com.ibm.websphere.sca.ServiceManager;
import commonj.sdo.DataObject;

/**
 * @author nikunj.panchal
 * 
 */

public class PerformProductOrderFeasibilityImpl {
	/**
	 * Default constructor.
	 */
	private static final Log log = LogFactory
			.getLog(PerformProductOrderFeasibilityImpl.class);

	public PerformProductOrderFeasibilityImpl() {
		super();
	}

	/**
	 * Return a reference to the component service instance for this
	 * implementation class. This method should be used when passing this
	 * service to a partner reference or if you want to invoke this component
	 * service asynchronously.
	 * 
	 * @generated (com.ibm.wbit.java)
	 */
	@SuppressWarnings("unused")
	private Object getMyService() {
		return (Object) ServiceManager.INSTANCE.locateService("self");
	}

	/**
	 * Method generated to support implementation of operation
	 * "performProductOrderFeasibility" defined for WSDL port type named
	 * "PerformProductOrderFeasibilityPT".
	 * 
	 * The presence of commonj.sdo.DataObject as the return type and/or as a
	 * parameter type conveys that it is a complex type. Please refer to the
	 * WSDL Definition for more information on the type of input, output and
	 * fault(s).
	 */
	public DataObject performProductOrderFeasibility(
			DataObject aProductOrderMessage) {

		DataObject resProductOrderMessage = null;
		DataObject header = null;
		String productId = "";
		String specificationId = "";
		// For Product
		DataObject productOrderDO = null;
		DataObject specification = null;

		List resProductOrderItemList = new ArrayList();
		List productOrderItemList = new ArrayList();
		try {
			// Response creation
			resProductOrderMessage = IndustrySupportUtil.createDO(
					IConstants.NS_PRODUCTORDERMESSAGE,
					IConstants.PRODUCTORDERMESSAGE);
			// Getting details from request
			// For header
			header = aProductOrderMessage.getDataObject(IConstants.DO_HEADER);
			productOrderDO = aProductOrderMessage
					.getDataObject(IConstants.PRODUCTORDER);
			List productOrderItemList1 = productOrderDO
					.getList(IConstants.PRODUCTORDERITEM);

			DataObject productOrderItem = (DataObject) productOrderItemList1
					.get(0);
			DataObject product = productOrderItem
					.getDataObject(IConstants.PRODUCT);

			// Getting ProductId
			if (product != null) {
				productId = product.getString("Id");
			}
			// Setting Header
			if (header != null) {
				header.setString(IConstants.MSGTYPE, IConstants.RESPONSE);
				resProductOrderMessage.set(IConstants.DO_HEADER, header);
			}
			/**
			 * Decompose Product
			 */

			DataObject rsProductOrderItem = IndustrySupportUtil.createDO(
					IConstants.NS_PRODUCTORDER, IConstants.PRODUCTORDERITEM);

			String desc = getDescripiton(productId);
			DataObject resProductOrder = resProductOrderMessage
					.createDataObject("productOrder");
			if (desc == null) {
				resProductOrder.setString("InteractionStatus", "Unavailable");
			} else {
				resProductOrder.setString("InteractionStatus", "Success");
			}

			rsProductOrderItem.setDataObject(IConstants.DO_PRODUCT, product);
			resProductOrderItemList.add(rsProductOrderItem);
			resProductOrder
					.setList("ProductOrderItem", resProductOrderItemList);

		} catch (Exception e) {

			header = resProductOrderMessage
					.createDataObject(IConstants.DO_HEADER);
			header = TelecomSupportUtil.createHeader(header, e);

			e.printStackTrace();
		}
		return resProductOrderMessage;
	}

	private String getDescripiton(String resourceOrderId) {
		String desc = null;

		InputStream file = null;
		Properties properties = new Properties();
		try {
			file = PerformProductOrderFeasibilityImpl.class
					.getResourceAsStream(IConstants.CHECKTECHNICALAVAILABILITYPROPERTIES);
			// System.out.println("File : " + file);
			properties.load(file);
			desc = (String) properties.get(resourceOrderId);
		} catch (IOException e) {
			log.error("Error reading properties file", e);
		} finally {
			try {
				if (file != null) {
					file.close();
				}
			} catch (IOException e) {
				log.error("Error while closing the file", e);
			}
		}
		return desc;
	}

}
