/***********************************************
 * Licensed Materials - Property of IBM
 * 
 * 5724-R31, 5655-S30
 * 
 * (C) Copyright IBM Corp. 2010 All Rights Reserved.
 * 
 * US Government Users Restricted Rights - Use, duplication or
 * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 ***********************************************
 */
package com.ibm.websphere.icp.telecom.reference.dynamicorderfulfillment.mock;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Properties;

import com.ibm.websphere.fabric.industry.support.util.IndustrySupportUtil;
import com.ibm.websphere.icp.industry.db.manager.IWicpDBFactoryConstants;
import com.ibm.websphere.icp.industry.db.manager.IWicpDBManager;
import com.ibm.websphere.icp.industry.db.manager.WicpDBFactory;
import com.ibm.websphere.icp.telecom.reference.dynamicorderfulfillment.Customermaster;
import com.ibm.websphere.icp.telecom.reference.dynamicorderfulfillment.util.IConstants;
import com.ibm.websphere.icp.telecom.reference.util.ValuesFromCharacteristics;
import com.ibm.websphere.sca.ServiceManager;
import commonj.sdo.DataObject;

public class QueryCustomerImpl {
	/**
	 * Default constructor.
	 */
	public QueryCustomerImpl() {
		super();
	}

	/**
	 * Return a reference to the component service instance for this
	 * implementation class. This method should be used when passing this
	 * service to a partner reference or if you want to invoke this component
	 * service asynchronously.
	 * 
	 * @generated (com.ibm.wbit.java)
	 */
	@SuppressWarnings("unused")
	private Object getMyService() {
		return (Object) ServiceManager.INSTANCE.locateService("self");
	}

	/**
	 * Method generated to support implementation of operation "findCustomer"
	 * defined for WSDL port type named "FindCustomerPT".
	 * 
	 * The presence of commonj.sdo.DataObject as the return type and/or as a
	 * parameter type conveys that it is a complex type. Please refer to the
	 * WSDL Definition for more information on the type of input, output and
	 * fault(s).
	 */
	public DataObject findCustomer(DataObject aCustomerMessage) {

		DataObject customer = aCustomerMessage.getDataObject("customer");
		String firstName = "";
		String middleName = "";
		String lastName = "";
		String mobilePhoneNumber = "";
		String fixedLinePhoneNumber = "";
		String email = "";

		DataObject party = customer.getDataObject("Party");
		/***
		 * Set the Title, FirstName,MiddleName & LastName with the
		 * SID.Customer->Name
		 * 
		 */
		String completeName = party.getString("Name");

		List partyCharacteristicValue = party.getList("CharacteristicValue");

		if (partyCharacteristicValue.size() > 0) {
			if (ValuesFromCharacteristics
					.characteristicValuesFromCharacteristicName(
							partyCharacteristicValue, "FirstName") != null)
				firstName = ValuesFromCharacteristics
						.characteristicValuesFromCharacteristicName(
								partyCharacteristicValue, "FirstName").get(0);

			if (ValuesFromCharacteristics
					.characteristicValuesFromCharacteristicName(
							partyCharacteristicValue, "MiddleName") != null)
				middleName = ValuesFromCharacteristics
						.characteristicValuesFromCharacteristicName(
								partyCharacteristicValue, "MiddleName").get(0);

			if (ValuesFromCharacteristics
					.characteristicValuesFromCharacteristicName(
							partyCharacteristicValue, "LastName") != null)
				lastName = ValuesFromCharacteristics
						.characteristicValuesFromCharacteristicName(
								partyCharacteristicValue, "LastName").get(0);
		}
		/**
		 * Set The Customer Address Information into the Characteristic Value
		 */
		List contactMediumList = (List) party.getList("ContactMedium");

		DataObject contactMedium = null;
		if (contactMediumList.size() > 0) {
			contactMedium = (DataObject) contactMediumList.get(0);
			List characteristicValueAlternateInfo = (List) contactMedium
					.getList("CharacteristicValue");

			if (ValuesFromCharacteristics
					.characteristicValuesFromCharacteristicName(
							characteristicValueAlternateInfo, "MobileNumber") != null)
				mobilePhoneNumber = ValuesFromCharacteristics
						.characteristicValuesFromCharacteristicName(
								characteristicValueAlternateInfo,
								"MobileNumber").get(0);
			if (ValuesFromCharacteristics
					.characteristicValuesFromCharacteristicName(
							characteristicValueAlternateInfo, "PhoneNumber") != null)
				fixedLinePhoneNumber = ValuesFromCharacteristics
						.characteristicValuesFromCharacteristicName(
								characteristicValueAlternateInfo, "PhoneNumber")
						.get(0);

			if (ValuesFromCharacteristics
					.characteristicValuesFromCharacteristicName(
							characteristicValueAlternateInfo, "Email") != null)
				email = ValuesFromCharacteristics
						.characteristicValuesFromCharacteristicName(
								characteristicValueAlternateInfo, "Email").get(
								0);
		}
		/**
		 * Create the maps to search the customer record
		 */
		Map<String, Object> mapParams = new HashMap<String, Object>();
		;
		mapParams.put("firstName", firstName);
		if(!middleName.equals("")){			
			mapParams.put("middleName", middleName);
		}		
		mapParams.put("lastName", lastName);
		mapParams.put("mobilePhoneNumber", mobilePhoneNumber);
		mapParams.put("fixedLinePhoneNumber", fixedLinePhoneNumber);
		mapParams.put("email", email);

		/**
		 * get the DbFactory and persist data
		 */
		Properties dbProperties = new Properties();
		dbProperties.setProperty(IWicpDBFactoryConstants.TYPE, "JPA");
		dbProperties.setProperty(IWicpDBFactoryConstants.PERSISTENCE_UNIT_NAME,
				IConstants.DB_ACCESS);

		IWicpDBManager wicpDbManager = WicpDBFactory.getDBManager(dbProperties);
		List searchedCustomerList = new ArrayList();

		try {
			if(!middleName.equals("")){
				searchedCustomerList = wicpDbManager.executeNamedQuery(
						"findCustomerByInfo", mapParams);
			}else{
				searchedCustomerList = wicpDbManager.executeNamedQuery(
					"findCustomerByName", mapParams);
				}
		} catch (Exception e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		DataObject rsCustomerCollectionMessage = IndustrySupportUtil
				.createDO(
						"http://www.ibm.com/xmlns/prod/websphere/fabric/2009/12/telecom/operations/inventory/schema/CustomerMessage",
						"CustomerCollectionMessage");
		List customerList = new ArrayList();

		if (searchedCustomerList.size() > 0) {
			for (int j = 0; j < searchedCustomerList.size(); j++) {
				Customermaster custMaster = new Customermaster();
				custMaster = (Customermaster) searchedCustomerList.get(j);
				DataObject rsCustomer = IndustrySupportUtil
						.createDO(
								"http://www.ibm.com/telecom/inventory/schema/customer/v3_0",
								"Customer");
				rsCustomer.set("Status", "Existing");

				DataObject rsParty = rsCustomer.createDataObject("Party");

				rsParty.setString("Id", String.valueOf(custMaster.getId()));

				DataObject specification = rsParty
						.createDataObject("Specification");
				specification.setString("Id", String.valueOf(custMaster
						.getAccount().getId()));

				List rsCharacteristicValueList = new ArrayList();

				rsParty.setString("Id", String.valueOf(custMaster.getId()));
				DataObject characteristicValueTitle = putValueInCharacterList(
						"Title", custMaster.getTitle());
				DataObject characteristicValueFirstName = putValueInCharacterList(
						"FirstName", custMaster.getFirstName());
				DataObject characteristicValueMiddleName = putValueInCharacterList(
						"MiddleName", custMaster.getMiddleName());
				DataObject characteristicValueLastName = putValueInCharacterList(
						"LastName", custMaster.getLastName());

				DataObject characteristicValueStreetNumber = putValueInCharacterList(
						"StreetNumber", custMaster.getStreetNr());
				DataObject characteristicValueStreetName = putValueInCharacterList(
						"StreetName", custMaster.getStreetName());
				DataObject characteristicValueStreetType = putValueInCharacterList(
						"Locality", custMaster.getStreetType());
				DataObject characteristicValueUnitName = putValueInCharacterList(
						"AppartmentName", custMaster.getUnitType());
				DataObject characteristicValueUnit = putValueInCharacterList(
						"AppartmentUnit", String
								.valueOf(custMaster.getUnitNr()));
				DataObject characteristicValueCITY = putValueInCharacterList(
						"City", custMaster.getCity());
				DataObject characteristicValueState = putValueInCharacterList(
						"State", custMaster.getState());
				DataObject characteristicValueCountry = putValueInCharacterList(
						"Country", custMaster.getCountry());
				DataObject characteristicValueZipcode = putValueInCharacterList(
						"Zipcode", custMaster.getPostCode());
				DataObject characteristicValuePreferedLanguage = putValueInCharacterList(
						"PreferredLanguage", custMaster.getPreferredLangauge());

				rsCharacteristicValueList.add(characteristicValueTitle);
				rsCharacteristicValueList.add(characteristicValueFirstName);
				rsCharacteristicValueList.add(characteristicValueMiddleName);
				rsCharacteristicValueList.add(characteristicValueLastName);

				rsCharacteristicValueList.add(characteristicValueStreetNumber);
				rsCharacteristicValueList.add(characteristicValueStreetName);
				rsCharacteristicValueList.add(characteristicValueStreetType);
				rsCharacteristicValueList.add(characteristicValueUnit);
				rsCharacteristicValueList.add(characteristicValueUnitName);
				rsCharacteristicValueList.add(characteristicValueCITY);
				rsCharacteristicValueList.add(characteristicValueState);
				rsCharacteristicValueList.add(characteristicValueCountry);
				rsCharacteristicValueList.add(characteristicValueZipcode);
				rsCharacteristicValueList.add(characteristicValuePreferedLanguage);
				rsParty.setList("CharacteristicValue",
						rsCharacteristicValueList);

				DataObject rsContactMedium = rsParty
						.createDataObject("ContactMedium");

				List rsAdditionalCharacteristicValueList = new ArrayList();

				DataObject characteristicValueMobileNumber = putValueInCharacterList(
						"MobileNumber", custMaster.getMobilePhoneNumber());
				DataObject characteristicValuePhoneNumber = putValueInCharacterList(
						"PhoneNumber", custMaster.getFixedLinePhoneNumber());

				DataObject characteristicValueEmail = putValueInCharacterList(
						"Email", custMaster.getEmail());

				rsAdditionalCharacteristicValueList
						.add(characteristicValueMobileNumber);
				rsAdditionalCharacteristicValueList
						.add(characteristicValuePhoneNumber);
				rsAdditionalCharacteristicValueList
						.add(characteristicValueEmail);

				rsContactMedium.setList("CharacteristicValue",
						rsAdditionalCharacteristicValueList);
				List rsContactMediumList = new ArrayList();
				rsContactMediumList.add(rsContactMedium);
				rsParty.setList("ContactMedium", rsContactMediumList);
				customerList.add(rsCustomer);
			}

			rsCustomerCollectionMessage.setList("customer", customerList);
		} else {
			DataObject rsCustomer = IndustrySupportUtil
					.createDO(
							"http://www.ibm.com/telecom/inventory/schema/customer/v3_0",
							"Customer");
			rsCustomer.set("Status", "New");
			customerList.add(rsCustomer);
			rsCustomerCollectionMessage.setList("customer", customerList);
		}
		return rsCustomerCollectionMessage;
	}

	private DataObject putValueInCharacterList(String feildName, String Value) {

		DataObject characteristicValue = IndustrySupportUtil.createDO(
				"http://www.ibm.com/telecom/common/schema/base/v3_0",
				"CharacteristicValue");
		DataObject characteristic = characteristicValue
				.createDataObject("Characteristic");
		characteristic.setString("Name", feildName);
		List valuestr = new ArrayList();
		valuestr.add(Value);
		characteristicValue.set("Value", valuestr);
		return characteristicValue;

	}

}
